<?php

require_once( 'WordpressConnectAdminPanel.php' );
require_once( 'WordpressConnectConstants.php' );

require_once( 'WordpressConnectWidgetActivity.php' );
require_once( 'WordpressConnectWidgetComments.php' );
require_once( 'WordpressConnectWidgetFacepile.php' );
require_once( 'WordpressConnectWidgetLikeBox.php' );
require_once( 'WordpressConnectWidgetLikeButton.php' );
require_once( 'WordpressConnectWidgetLiveStream.php' );
require_once( 'WordpressConnectWidgetLogin.php' );
require_once( 'WordpressConnectWidgetRecommendations.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date May 28 2010
 * 
 * @file WordpressConnect.php
 * 
 * This class serves as the main class for the Wordpress Connect 
 * wordpress plugin
 */
class WordpressConnect {
	
	/**
	 * @var WordpressConnectAdminPanel
	 */
	var $adminPanel;	
	
	/**
	 * Creates a new WordpressConnect object
	 * 
	 * @since	1.0
	 * 
	 */
	function WordpressConnect(){
	
		$this->add_init_hook();
	}	
	
	/**
	 * This function is executed when the plugin is actived.
	 * 
	 * @since	1.01
	 */
	function activate(){
		
		//global $wpdb;
		
		if ( get_option( WPC_OPTIONS_LANGUAGE ) == '' ){
			update_option( WPC_OPTIONS_LANGUAGE, 'en_US' );	
		}
		
		if ( get_option( WPC_OPTIONS_APP_ID ) == '' ){
			update_option( WPC_OPTIONS_APP_ID, WPC_DEFAULT_APP_ID );	
		}		
	}	
	
	/**
	 * This function is executed when the plugin is deactived. 
	 * 
	 * @since	1.01
	 */
	function deactivate(){
	}	
	
// ---------------------------- WP Hooks - START ------------------------- //
	
	/**
	 * Adds init wordpress hook. 
	 * 
	 * @since	1.01
	 */
	function add_init_hook(){
		add_action( 'admin_menu', array( &$this, 'add_admin_panel' ) );
		add_action( 'init', array( &$this, 'add_wp_hooks' ) );
		add_action( 'widgets_init', array( &$this, 'load_widget' ) );

		add_action( 'wp_head', array( &$this, 'add_like_meta' ) );
		add_action( 'wp_footer', array( &$this, 'add_fb_js' ) );
	}
	
	/**
	 * Adds wordpress hooks (and filters) necessary for this plugin
	 * 
	 * @private
	 * @since	1.01
	 */
	function add_wp_hooks(){
		
		add_filter( 'the_content', array( &$this, 'add_post_modules' ) );
		
		// add necessary content to the header
		
			// add like meta tags
		// add necessary content to the post content
			// add comments / login button
		// add necessary content to the footer		
			// add the facebook JS api initialization
		
		// filters
		//add_filter( 'query_vars', array( &$this, 'handleFilterQueryVars') );
		//add_filter( 'post_rewrite_rules', array( &$this, 'handleFilterPostRewriteRules') );
		
	}

	/**
	 * Adds plugin's admin panel to the wp dashboard
	 * 
	 * @private 
	 * @since	1.0
	 */
	function add_admin_panel(){
		
		$this->adminPanel = new WordpressConnectAdminPanel();
		
	}

	/**
	 * Registers the Wordpress Connect widget
	 * 
	 * @since	1.0
	 */
	function load_widget() {
		
		register_widget( 'WordpressConnectWidgetActivity' );
		register_widget( 'WordpressConnectWidgetComments' );
		register_widget( 'WordpressConnectWidgetFacepile' );
		register_widget( 'WordpressConnectWidgetLikeBox' );
		register_widget( 'WordpressConnectWidgetLikeButton' );
		register_widget( 'WordpressConnectWidgetLiveStream' );
		register_widget( 'WordpressConnectWidgetLogin' );
		register_widget( 'WordpressConnectWidgetRecommendations' );
	}
	
	
	function add_like_meta(){
		
		global $post;
		
?>
		<!-- Wordpress Connect meta v<?php echo WPC_VERSION; ?>--> 
		<meta property="og:site_name" content="<?php bloginfo('name'); ?>"/>
		<meta property="og:image" content="<?php echo get_option( WPC_OPTIONS_IMAGE_URL ); ?>" />
		<meta property="fb:admins" content="<?php echo get_option( WPC_OPTIONS_APP_ADMINS ); ?>"/>
<?php		
		
		if( is_home() ){
			
			$description = str_replace("\n", " ", get_option( WPC_OPTIONS_DESCRIPTION ) );
			
?>
		<!-- Wordpress Connect meta home v<?php echo WPC_VERSION; ?>--> 	
		<meta property="og:title" content="<?php bloginfo('name'); ?>" />
		<meta property="og:type" content="blog" />
		<meta property="og:description" content="<?= $description; ?>" />
		<meta property="og:url" content="<?php bloginfo('url'); ?>"/>
<?php
		}
		else if ( is_single() ){
?>
		<!-- Wordpress Connect meta post v<?php echo WPC_VERSION; ?>--> 
		<meta property="og:title" content="<?php single_post_title(); ?>" />
		<meta property="og:type" content="article" />
		<meta property="og:url" content="<?php the_permalink() ?>"/>	
<?php
		}
		else if ( is_category() ){
			$cat_id = get_cat_id( single_cat_title('', FALSE) );
			$cat_url = get_category_link( $cat_id ); 
?>
		<!-- Wordpress Connect meta category v<?php echo WPC_VERSION; ?>-->
		<meta property="og:title" content="<?php bloginfo('name'); ?> - <?php single_cat_title(); ?>" />
		<meta property="og:type" content="website" />
		<meta property="og:url" content="<?= $cat_url; ?>"/>	
<?php
		}
		else if ( is_page() ){
?>
		<!-- Wordpress Connect meta page v<?php echo WPC_VERSION; ?>-->
		<meta property="og:title" content="<?php bloginfo('name'); ?> - <?php single_post_title(); ?>" />
		<meta property="og:type" content="website" />
		<meta property="og:url" content="<?php the_permalink() ?>"/>
<?php
		}
		
	}
	
	function add_fb_js(){
?>
	<!-- Wordpress Connect FBJS v<?php echo WPC_VERSION; ?>--> 
    <div id="fb-root"></div>
    <script src="http://connect.facebook.net/<?php echo get_option( WPC_OPTIONS_LANGUAGE ); ?>/all.js"></script>
    <script>
		FB.init({appId: '<?php echo get_option( WPC_OPTIONS_APP_ID ); ?>', status: true, cookie: true, xfbml: true});
    </script>	
<?php		
	}
	
	function add_post_modules( $content ){
		
		global $post;
		
		// TODO
		// permalink to the post
		$site = get_permalink( $post->ID );
		
		// add the enabled modules
		$modules = "\n<!-- Wordpress Connect Modules v" . WPC_VERSION . " -->";
		
		$comments = array();
		$comments['enabled'] = get_option( WPC_OPTIONS_COMMENTS_ENABLED ) == 1;
		
		if ( $comments['enabled'] === TRUE ){
			$comments['comments_number'] = get_option( WPC_OPTIONS_COMMENTS_NUMBER );
			$comments['width'] = get_option( WPC_OPTIONS_COMMENTS_WIDTH );	
			
			$modules .= WordpressConnectWidgetComments::getWidgetCode( 
				$site, 
				$comments['width'], 
				$comments['comments_number'] 
			);
		}
		else {
			$like_button = array();
			$like_button['enabled'] = get_option( WPC_OPTIONS_LIKE_BUTTON_ENABLED ) == 1;
			
			if ( $like_button['enabled'] === TRUE ){
				 
				$like_button['type'] = get_option( WPC_OPTIONS_LIKE_BUTTON_TYPE );
				$like_button['layout'] = get_option( WPC_OPTIONS_LIKE_BUTTON_LAYOUT );
				$like_button['show_faces'] = get_option( WPC_OPTIONS_LIKE_BUTTON_SHOW_FACES ) == 1;
				$like_button['width'] = get_option( WPC_OPTIONS_LIKE_BUTTON_WIDTH ); 
				$like_button['height'] = get_option( WPC_OPTIONS_LIKE_BUTTON_HEIGHT );
				$like_button['verb'] = get_option( WPC_OPTIONS_LIKE_BUTTON_VERB );
				$like_button['font'] = get_option( WPC_OPTIONS_LIKE_BUTTON_FONT );
				$like_button['scheme'] = get_option( WPC_OPTIONS_LIKE_BUTTON_COLOR_SCHEME );

				$modules .= WordpressConnectWidgetLikeButton::getWidgetCode(
					$like_button['type'],
					$site,
					$like_button['layout'],
					( $like_button['show_faces'] ) ? 'true' : 'false',
					$like_button['width'], 
					$like_button['height'], 
					$like_button['verb'],
					$like_button['font'],
					$like_button['scheme']
				);
				 
			}
		}
		
		return $content . $modules;
		
	}
	
}

?>