<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2010
 * 
 * @file WordpressConnectAdminPanel.php
 * 
 * This class provides functionality for the wordpress dashboard admin
 * panel for the Wordpress Connect wordpress plugin
 */
class WordpressConnectAdminPanel {


	/**
	 * Creates a new instance of WordpressConnectAdminPanel
	 * 
	 * @since	1.0
	 * 
	 */
	function WordpressConnectAdminPanel(){
		
		add_menu_page(
			"Connect", 
			"Connect", 
			8, 
			"wordpress-connect", 
			array( &$this, 'menuPageHandler' ) 
		);
		
		add_submenu_page(
			"wordpress-connect",
			"Comments",
			"Comments",
			8,
			"wordpress-connect/comments",
			array( &$this, 'commentsHandler' )
		);		
		
		add_submenu_page(
			"wordpress-connect",
			"Like Button",
			"Like Button",
			8,
			"wordpress-connect/like-button",
			array( &$this, 'likeButtonHandler' )
		);

		if ( isset( $_POST['submit_save_changes'] ) ){
			$this->updateOptions();
		}
		
		if ( isset( $_POST['submit_save_like_button'] ) ){
			$this->updateLikeButtonOptions();
		}
		if ( isset( $_POST['submit_save_comments'] ) ){
			$this->updateCommentsOptions();
		}
		
	}

	/**
	 * This function is executed when the user clicks on the Wordpress 
	 * Connect link in the Wordpress Dashboard
	 */
	function menuPageHandler(){
		
?>		
	
	<div class="wrap">
		
		<div id="icon-options-general" class="icon32"><br/></div>		
		
		<h2>Wordpress Connect Settings</h2>

<?php if ($custom_msg) { ?>
		<div class="updated fade below-h2" id="message" style="background-color: rgb(255, 251, 204);"><p><?=$custom_msg;?></p></div>
<?php } ?>

		<form method="post" class="" action="?page=wordpress-connect"; ?>
		<?php wp_nonce_field(); ?>
			
			<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row">
							<label for="language">Language:</label>
						</th>
						<td>
							<select id="language" name="language" ><?php $language = get_option( WPC_OPTIONS_LANGUAGE ); ?>
								<option <?php echo ( $language == 'en_US' ) ? 'selected="selected"' : ''; ?> value="en_US">English (US)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'en_GB' ) ? 'selected="selected"' : ''; ?> value="en_GB">English (UK)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ar_AR' ) ? 'selected="selected"' : ''; ?> value="ar_AR">Arabic&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'de_DE' ) ? 'selected="selected"' : ''; ?> value="de_DE">German&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'fr_FR' ) ? 'selected="selected"' : ''; ?> value="fr_FR">French&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'it_IT' ) ? 'selected="selected"' : ''; ?> value="it_IT">Italian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ru_RU' ) ? 'selected="selected"' : ''; ?> value="ru_RU">Russian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'es_ES' ) ? 'selected="selected"' : ''; ?> value="es_ES">Spanish (Spain)&nbsp;&nbsp;&nbsp;</option>
								
								<option <?php echo ( $language == 'af_ZA' ) ? 'selected="selected"' : ''; ?> value="af_ZA">Afrikaans&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sq_AL' ) ? 'selected="selected"' : ''; ?> value="sq_AL">Albanian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'hy_AM' ) ? 'selected="selected"' : ''; ?> value="hy_AM">Armenian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ay_BO' ) ? 'selected="selected"' : ''; ?> value="ay_BO">Aymara&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'az_AZ' ) ? 'selected="selected"' : ''; ?> value="az_AZ">Azeri&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'be_BY' ) ? 'selected="selected"' : ''; ?> value="be_BY">Belarusian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'bn_IN' ) ? 'selected="selected"' : ''; ?> value="bn_IN">Bengali&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'bs_BA' ) ? 'selected="selected"' : ''; ?> value="bs_BA">Bosnian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'bg_BG' ) ? 'selected="selected"' : ''; ?> value="bg_BG">Bulgarian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ca_ES' ) ? 'selected="selected"' : ''; ?> value="ca_ES">Catalan&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ck_US' ) ? 'selected="selected"' : ''; ?> value="ck_US">Cherokee&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'zh_CN' ) ? 'selected="selected"' : ''; ?> value="zh_CN">Chinese (China)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'zh_HK' ) ? 'selected="selected"' : ''; ?> value="zh_HK">Chinese (Hong Kong)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'zh_TW' ) ? 'selected="selected"' : ''; ?> value="zh_TW">Chinese (Taiwan)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'hr_HR' ) ? 'selected="selected"' : ''; ?> value="hr_HR">Croatian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'cs_CZ' ) ? 'selected="selected"' : ''; ?> value="cs_CZ">Czech&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'da_DK' ) ? 'selected="selected"' : ''; ?> value="da_DK">Danish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'nl_NL' ) ? 'selected="selected"' : ''; ?> value="nl_NL">Dutch&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'nl_BE' ) ? 'selected="selected"' : ''; ?> value="nl_BE">Dutch (Belgi&euml;)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'en_PL' ) ? 'selected="selected"' : ''; ?> value="en_PL">English (Pirate)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'en_UD' ) ? 'selected="selected"' : ''; ?> value="en_UD">English (Upside Down)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'eo_EO' ) ? 'selected="selected"' : ''; ?> value="eo_EO">Esperanto&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'et_EE' ) ? 'selected="selected"' : ''; ?> value="et_EE">Estoninan&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'fo_FO' ) ? 'selected="selected"' : ''; ?> value="fo_FO">Faroese&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'tl_PH' ) ? 'selected="selected"' : ''; ?> value="tl_PH">Filipino&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'fi_FI' ) ? 'selected="selected"' : ''; ?> value="fi_FI">Finnish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'fr_CA' ) ? 'selected="selected"' : ''; ?> value="fr_CA">French (Canada)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'gl_ES' ) ? 'selected="selected"' : ''; ?> value="gl_ES">Galician&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ka_GE' ) ? 'selected="selected"' : ''; ?> value="ka_GE">Georgian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'el_GR' ) ? 'selected="selected"' : ''; ?> value="el_GR">Greek&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'gn_PY' ) ? 'selected="selected"' : ''; ?> value="gn_PY">Guaran&iacute;&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'gu_IN' ) ? 'selected="selected"' : ''; ?> value="gu_IN">Gujarati&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'he_IL' ) ? 'selected="selected"' : ''; ?> value="he_IL">Hebrew&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'hi_IN' ) ? 'selected="selected"' : ''; ?> value="hi_IN">Hindi&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'hu_HU' ) ? 'selected="selected"' : ''; ?> value="hu_HU">Hungarian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'is_IS' ) ? 'selected="selected"' : ''; ?> value="is_IS">Icelandic&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'id_ID' ) ? 'selected="selected"' : ''; ?> value="id_ID">Indonesian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ga_IE' ) ? 'selected="selected"' : ''; ?> value="ga_IE">Irish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ja_JP' ) ? 'selected="selected"' : ''; ?> value="ja_JP">Japanese&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'jv_ID' ) ? 'selected="selected"' : ''; ?> value="jv_ID">Javanese&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'kn_IN' ) ? 'selected="selected"' : ''; ?> value="kn_IN">Kannada&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'kk_KZ' ) ? 'selected="selected"' : ''; ?> value="kk_KZ">Kazakh&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'km_KH' ) ? 'selected="selected"' : ''; ?> value="km_KH">Khmer&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'tl_ST' ) ? 'selected="selected"' : ''; ?> value="tl_ST">Klingon&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ko_KR' ) ? 'selected="selected"' : ''; ?> value="ko_KR">Korean&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ku_TR' ) ? 'selected="selected"' : ''; ?> value="ku_TR">Kurdish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'la_VA' ) ? 'selected="selected"' : ''; ?> value="la_VA">Latin&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'lv_LV' ) ? 'selected="selected"' : ''; ?> value="lv_LV">Latvian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'fb_LT' ) ? 'selected="selected"' : ''; ?> value="fb_LT">Leet Speak&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'li_NL' ) ? 'selected="selected"' : ''; ?> value="li_NL">Limburgish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'lt_LT' ) ? 'selected="selected"' : ''; ?> value="lt_LT">Lithuanian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'mk_MK' ) ? 'selected="selected"' : ''; ?> value="mk_MK">Macedonian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'mg_MG' ) ? 'selected="selected"' : ''; ?> value="mg_MG">Malagasy&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ms_MY' ) ? 'selected="selected"' : ''; ?> value="ms_MY">Malay&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ml_IN' ) ? 'selected="selected"' : ''; ?> value="ml_IN">Malayalam&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'mt_MT' ) ? 'selected="selected"' : ''; ?> value="mt_MT">Maltese&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'mr_IN' ) ? 'selected="selected"' : ''; ?> value="mr_IN">Marathi&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'mn_MN' ) ? 'selected="selected"' : ''; ?> value="mn_MN">Mongolian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ne_NP' ) ? 'selected="selected"' : ''; ?> value="ne_NP">Nepali&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'mg_MG' ) ? 'selected="selected"' : ''; ?> value="mg_MG">Malagasy&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ko_KR' ) ? 'selected="selected"' : ''; ?> value="ko_KR">Korean&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'nb_NO' ) ? 'selected="selected"' : ''; ?> value="nb_NO">Norwegian (bokmal)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'nn_NO' ) ? 'selected="selected"' : ''; ?> value="nn_NO">Norwegian (nynorsk)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'se_NO' ) ? 'selected="selected"' : ''; ?> value="se_NO">Northern S&aacute;mi&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ps_AF' ) ? 'selected="selected"' : ''; ?> value="ps_AF">Pashto&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'fa_IR' ) ? 'selected="selected"' : ''; ?> value="fa_IR">Persian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'pl_PL' ) ? 'selected="selected"' : ''; ?> value="pl_PL">Polish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'pt_BR' ) ? 'selected="selected"' : ''; ?> value="pt_BR">Portugese (Brazil)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'pt_PT' ) ? 'selected="selected"' : ''; ?> value="pt_PT">Portugese (Portugal)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'qu_PE' ) ? 'selected="selected"' : ''; ?> value="qu_PE">Quechua&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'pa_IN' ) ? 'selected="selected"' : ''; ?> value="pa_IN">Punjabi&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ro_RO' ) ? 'selected="selected"' : ''; ?> value="ro_RO">Romanian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'rm_CH' ) ? 'selected="selected"' : ''; ?> value="rm_CH">Romansh&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sa_IN' ) ? 'selected="selected"' : ''; ?> value="sa_IN">Sanskrit&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sr_RS' ) ? 'selected="selected"' : ''; ?> value="sr_RS">Serbian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'so_SO' ) ? 'selected="selected"' : ''; ?> value="so_SO">Somali&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sk_SK' ) ? 'selected="selected"' : ''; ?> value="sk_SK">Slovak&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sl_SL' ) ? 'selected="selected"' : ''; ?> value="sl_SL">Slovenian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'es_CL' ) ? 'selected="selected"' : ''; ?> value="es_CL">Spanish (Chile)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'es_CO' ) ? 'selected="selected"' : ''; ?> value="es_CO">Spanish (Colombia)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'es_MX' ) ? 'selected="selected"' : ''; ?> value="es_MX">Spanish (Mexico)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'es_VE' ) ? 'selected="selected"' : ''; ?> value="es_VE">Spanish (Venezuela)&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sy_SY' ) ? 'selected="selected"' : ''; ?> value="sy_SY">Syriac&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sw_KE' ) ? 'selected="selected"' : ''; ?> value="sw_KE">Swahili&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'sv_SE' ) ? 'selected="selected"' : ''; ?> value="sv_SE">Swedish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'tg_TJ' ) ? 'selected="selected"' : ''; ?> value="tg_TJ">Tajik&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ta_IN' ) ? 'selected="selected"' : ''; ?> value="ta_IN">Tamil&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'tt_RU' ) ? 'selected="selected"' : ''; ?> value="tt_RU">Tatar&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'te_IN' ) ? 'selected="selected"' : ''; ?> value="te_IN">Telugu&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'th_TH' ) ? 'selected="selected"' : ''; ?> value="th_TH">Thai&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'tr_TR' ) ? 'selected="selected"' : ''; ?> value="tr_TR">Turkish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'uk_UA' ) ? 'selected="selected"' : ''; ?> value="uk_UA">Ukrainian&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'ur_PK' ) ? 'selected="selected"' : ''; ?> value="ur_PK">Urdu&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'uz_UZ' ) ? 'selected="selected"' : ''; ?> value="uz_UZ">Uzbek&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'vi_VN' ) ? 'selected="selected"' : ''; ?> value="vi_VN">Vietnamese&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'cy_GB' ) ? 'selected="selected"' : ''; ?> value="cy_GB">Welsh&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'xh_ZA' ) ? 'selected="selected"' : ''; ?> value="xh_ZA">Xhosa&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'yi_DE' ) ? 'selected="selected"' : ''; ?> value="yi_DE">Yiddish&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $language == 'xh_ZA' ) ? 'selected="selected"' : ''; ?> value="zu_ZA">Zulu&nbsp;&nbsp;&nbsp;</option>
							</select> 	
							<span class="description">
								The default Facebook Connect language.
							</span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="app_id">APP ID:</label>
						</th>
						<td>
							<input id="app_id" class="regular-text code" type="text" value="<?php echo get_option( WPC_OPTIONS_APP_ID ); ?>" name="app_id" />
							<br />
							<span class="description">
								The ID of the Facebook Connect Application. You can create a new Facebook Application <a href="http://developers.facebook.com/setup/" target="_blank" rel="nofollow">here</a>.  
							</span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="app_admins">APP Admin:</label>
						</th>
						<td>
							<input id="app_admins" class="regular-text code" type="text" value="<?php echo get_option( WPC_OPTIONS_APP_ADMINS ); ?>" name="app_admins" />
							<br />
							<span class="description">
								Comma separated Facebook ids - gives the specified users the ability to review the Like stats.
							</span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="image_url">Image URL:</label>
						</th>
						<td>
							<input id="image_url" class="regular-text code" type="text" value="<?php echo get_option( WPC_OPTIONS_IMAGE_URL ); ?>" name="image_url" />
							<br />
							<span class="description">
								URL to the thumbnail for Facebook Stream posts.
							</span>
						</td>
					</tr>				
					<tr valign="top">
						<th scope="row">
							<label for="description">Description:</label>
						</th>
						<td>
							<textarea name="description" id="description" rows="5" cols="60" ><?php echo get_option( WPC_OPTIONS_DESCRIPTION ); ?></textarea>
							<br/ >
							<span class="description">
								Description of the blog for Facebook Like and Stream posts.
							</span>
						</td>
					</tr>				
				</tbody>
			</table>
			<p class="submit">
				<input class="button-primary" type="submit" value="Save Changes" name="submit_save_changes" id="submit_save_changes" />
			</p>
		</form>		
		
	</div>
	
<?php
	}
	
	function commentsHandler(){

		if ( !empty( $this->message ) ){
			echo $this->message;
			$this->message = ""; 			
		}	
		
?>

	<div class="wrap">
		
		<div id="icon-options-general" class="icon32"><br/></div>		
		
		<h2>Comments Settings</h2>
		
		<form method="post" class="" action="?page=wordpress-connect/comments">
			<?php wp_nonce_field(); ?>
			
			<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row">
							<label for="comments_enabled">Enabled:</label>
						</th>
						<td>
							<input type="checkbox" <?php echo ( get_option( WPC_OPTIONS_COMMENTS_ENABLED ) == 1 ) ? 'checked="checked"' : ''; ?> id="comments_enabled" name="comments_enabled" />
							<span class="description">
								Adds the Comments Module to your posts.
							</span>							
						</td>
					</tr>	
					
					<tr valign="top">
						<th scope="row">
							<label for="comments_number">Number of Comments:</label>
						</th>
						<td>
							<input type="text" name="comments_number" id="comments_number" size="8" value="<?php echo get_option( WPC_OPTIONS_COMMENTS_NUMBER ); ?> "/>
							<span class="description">
								The number of comments to display, or 0 to hide all comments.
							</span>							
						</td>
					</tr>
					
					<tr valign="top">
						<th scope="row">
							<label for="comments_width">Width:</label>
						</th>
						<td>
							<input type="text" name="comments_width" id="comments_width" size="8" value="<?php echo get_option( WPC_OPTIONS_COMMENTS_WIDTH ); ?> "/>
							<span class="description">
								The width of the Comments Module in pixels.
							</span>							
						</td>
					</tr>
							
				</tbody>
			</table>

			<p class="submit">
				<input class="button-primary" type="submit" value="Save Changes" name="submit_save_comments" id="submit_save_comments" />
			</p>
			
		</form>
		
	</div>

<?php		

	}
	
	function likeButtonHandler(){
		
		if ( !empty( $this->message ) ){
			echo $this->message;
			$this->message = ""; 			
		}
		
?>

	<div class="wrap">
		
		<div id="icon-options-general" class="icon32"><br/></div>		
		
		<h2>Like Button Settings</h2>

		<?php if ( get_option( WPC_OPTIONS_COMMENTS_ENABLED ) == 1 ){ ?>
		<div id="like-button-warning" class="updated fade">
			<p><strong>Comments Module is enabled!</strong> The standalone Like Button will NOT appear (the Like Button is already a part of the Comments Module already )</p>
		</div>
		<?php } ?>
		
		<form method="post" class="" action="?page=wordpress-connect/like-button">
			<?php wp_nonce_field(); ?>
			
			<p>The following settings are for the Like Buttons which appear at the end of your posts. The Like Button Widget Settings are editable directly from the <a href="widget.php" target="_blank">widgets page</a> (after you have added a widget to the sidebar).</p>
			
			<table class="form-table">
				<tbody>
					<tr valign="top">
						<th scope="row">
							<label for="like_button_enabled">Enabled:</label>
						</th>
						<td>
							<input type="checkbox" <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_ENABLED ) == 1 ) ? 'checked="checked"' : ''; ?> id="like_button_enabled" name="like_button_enabled" />
							<span class="description">
								Adds the Like Button to your posts.
							</span>							
						</td>
					</tr>				
					<tr valign="top">
						<th scope="row">
							<label for="like_button_type">Type:</label>
						</th>
						<td>
							<select id="like_button_type" name="like_button_type" >
								<option <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_TYPE ) == WPC_TYPE_IFRAME ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_IFRAME; ?>"><?php echo WPC_TYPE_IFRAME; ?>&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_TYPE ) == WPC_TYPE_XFBML ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_XFBML; ?>"><?php echo WPC_TYPE_XFBML;?>&nbsp;&nbsp;&nbsp;</option>
							</select> 						
							<span class="description">
								The rendering type of the button.
							</span>
						</td>
					</tr>		
					<tr valign="top">
						<th scope="row">
							<label for="like_button_layout">Layout Style:</label>						
						</th>
						<td>
							<select id="like_button_layout" name="like_button_layout" >
								<option <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_LAYOUT ) == 'standard' ) ? 'selected="selected"' : ''; ?> value="standard">standard&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_LAYOUT ) == 'button_count' ) ? 'selected="selected"' : ''; ?> value="button_count">button_count&nbsp;&nbsp;&nbsp;</option>
							</select> 					
							<span class="description">
								Determines the amount of social context next to the button.
							</span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="like_button_show_faces">Show Faces:</label>
						</th>
						<td>
							<input type="checkbox" <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_SHOW_FACES ) == 1 ) ? 'checked="checked"' : ''; ?> id="like_button_show_faces" name="like_button_show_faces" />
							<span class="description">
								Show profile pictures below the button.
							</span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="like_button_width">Width:</label>					
						</th>
						<td>
							<input type="text" name="like_button_width" id="like_button_width" size="8" value="<?php echo get_option( WPC_OPTIONS_LIKE_BUTTON_WIDTH ); ?> "/>
							<span class="description">
								The width of the button in pixels.
							</span>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">
							<label for="like_button_height>">Height:</label>						
						</th>
						<td>
							<input type="text" name="like_button_height" id="like_button_height" size="8" value="<?php echo get_option( WPC_OPTIONS_LIKE_BUTTON_HEIGHT ); ?>" />
							<span class="description">
								The height of the button in pixels (iframe type only)
							</span>
						</td>
					</tr>
					
					<tr valign="top">
						<th scope="row">
							<label for="like_button_verb">Verb to display:</label>						
						</th>
						<td>
							<select id="like_button_verb>" name="like_button_verb" >
								<option <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_VERB ) == 'like' ) ? 'selected="selected"' : ''; ?> value="like">like&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( get_option( WPC_OPTIONS_LIKE_BUTTON_VERB ) == 'recommend' ) ? 'selected="selected"' : ''; ?> value="recommend">recommend&nbsp;&nbsp;&nbsp;</option>
							</select>						
							<span class="description">
								The verb to display in the button. Currently only 'like' and 'recommend' are supported.
							</span>
						</td>
					</tr>
					
					<tr valign="top">
						<th scope="row">
							<label for="like_button_font">Font:</label>					
						</th>
						<td>
							<select id="like_button_font" name="like_button_font" ><?php $like_button_font = get_option( WPC_OPTIONS_LIKE_BUTTON_FONT ); ?>
								<option <?php echo ( $like_button_font == '' ) ? 'selected="selected"' : ''; ?>></option>
								<option <?php echo ( $like_button_font == 'arial' ) ? 'selected="selected"' : ''; ?> value="arial">arial&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $like_button_font == 'lucida grande' ) ? 'selected="selected"' : ''; ?> value="lucida grande">lucida grande&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $like_button_font == 'segoe ui' ) ? 'selected="selected"' : ''; ?> value="segoe ui">segoe ui&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $like_button_font == 'tahoma' ) ? 'selected="selected"' : ''; ?> value="tahoma">tahoma&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $like_button_font == 'trebuchet ms' ) ? 'selected="selected"' : ''; ?> value="trebuchet ms">trebuchet ms&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $like_button_font == 'verdana' ) ? 'selected="selected"' : ''; ?> value="verdana">verdana&nbsp;&nbsp;&nbsp;</option>				
							</select> 						
							<span class="description">
								The font of the button.
							</span>
						</td>
					</tr>

					<tr valign="top">
						<th scope="row">
							<label for="like_button_color_scheme">Color Scheme:</label>
						</th>
						<td>
							<select id="like_button_color_scheme" name="like_button_color_scheme" ><?php $like_button_color_scheme = get_option( WPC_OPTIONS_LIKE_BUTTON_COLOR_SCHEME ); ?>
								<option <?php echo ( $like_button_color_scheme == 'light' ) ? 'selected="selected"' : ''; ?> value="light">ligth&nbsp;&nbsp;&nbsp;</option>
								<option <?php echo ( $like_button_color_scheme == 'dark' ) ? 'selected="selected"' : ''; ?> value="dark">dark&nbsp;&nbsp;&nbsp;</option>
							</select> 
							<span class="description">
								The color scheme of the button.
							</span>
						</td>
					</tr>
				</tbody>
			</table>			
			
			<p class="submit">
				<input class="button-primary" type="submit" value="Save Changes" name="submit_save_like_button" id="submit_save_like_button" />
			</p>			
		</form>		
		
	</div>

<?php		
		
	}

	/**
	 * Updates plugin options after user submits the settings page form
	 * @return 
	 */	
	function updateOptions(){
		
		if ( isset( $_POST['language'] ) ){
			update_option( WPC_OPTIONS_LANGUAGE, trim( $_POST['language'] ) );
		}
		else {
			update_option( WPC_OPTIONS_LANGUAGE, 'en_US' );
		}
		if ( isset( $_POST['app_id'] ) ){
			update_option( WPC_OPTIONS_APP_ID, trim( $_POST['app_id'] ) );
		}
		if ( isset( $_POST['app_admins'] ) ){
			update_option( WPC_OPTIONS_APP_ADMINS, trim( $_POST['app_admins'] ) );
		}
		if ( isset( $_POST['image_url'] ) ){
			update_option( WPC_OPTIONS_IMAGE_URL, trim( $_POST['image_url'] ) );
		}				
		if ( isset( $_POST['description'] ) ){
			update_option( WPC_OPTIONS_DESCRIPTION, trim( $_POST['description'] ) );
		}				
				
	}
	
	/**
	 * Updates plugin options after user submits the settings page form
	 * @return 
	 */	
	function updateCommentsOptions(){
		
		if ( isset( $_POST['comments_enabled'] ) ){
			update_option( WPC_OPTIONS_COMMENTS_ENABLED, 1 );
		}		
		else {
			update_option( WPC_OPTIONS_COMMENTS_ENABLED, 0 );
		}
		
		if ( isset( $_POST['comments_number'] ) ){
			update_option( WPC_OPTIONS_COMMENTS_NUMBER, trim( $_POST['comments_number'] ) );
		}
		
		if ( isset( $_POST['comments_width'] ) ){
			update_option( WPC_OPTIONS_COMMENTS_WIDTH, trim( $_POST['comments_width'] ) );
		}				
				
	}
	
	/**
	 * Updates plugin options after user submits the settings page form
	 * @return 
	 */
	function updateLikeButtonOptions(){
		
		if ( isset( $_POST['like_button_enabled'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_ENABLED, 1 );	
		}
		else {
			update_option( WPC_OPTIONS_LIKE_BUTTON_ENABLED, 0 );
		}
		
		if ( isset( $_POST['like_button_type'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_TYPE, trim( $_POST['like_button_type'] ) );
		}

		if ( isset( $_POST['like_button_layout'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_LAYOUT, trim( $_POST['like_button_layout'] ) );
		}		

		if ( isset( $_POST['like_button_show_faces'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_SHOW_FACES, 1 );	
		}
		else {
			update_option( WPC_OPTIONS_LIKE_BUTTON_SHOW_FACES, 0 );
		}

		if ( isset( $_POST['like_button_width'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_WIDTH, trim( $_POST['like_button_width'] ) );
		}	
		
		if ( isset( $_POST['like_button_height'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_HEIGHT, trim( $_POST['like_button_height'] ) );
		}
		
		if ( isset( $_POST['like_button_verb'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_VERB, trim( $_POST['like_button_verb'] ) );
		}	

		//if ( isset( $_POST['like_button_font'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_FONT, trim( $_POST['like_button_font'] ) );
		//}	

		if ( isset( $_POST['like_button_color_scheme'] ) ){
			update_option( WPC_OPTIONS_LIKE_BUTTON_COLOR_SCHEME, trim( $_POST['like_button_color_scheme'] ) );
		}	

	}
}

?>