<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetActivity.php
 * 
 * This class provides methods for the Activity Feed widget
 */
class WordpressConnectWidgetActivity extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetActivity
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetActivity() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-activity', 
			'description' => 'Wordpress Connect Activity Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-activity', 'WPC Activity Widget', $widget_ops );		
		
	}
	
	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $type, $domain, $width, $height, $header, $colorscheme = 'light', $font = '', $border_color = ''  ){
			
		echo "\n", '<!-- Wordpress Connect Activity Widget v',WPC_VERSION,'-->' , "\n";
		
		if ( $type == WPC_TYPE_IFRAME || empty( $type ) ){
			
			echo '<iframe src="http://www.facebook.com/plugins/activity.php?site=',urlencode($domain),'&amp;width=',$width,'&amp;height=',$height,'&amp;header=',$header,'&amp;colorscheme=',$colorscheme,'&amp;font=',$font,'&amp;border_color=',$border_color,'" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:',$width,'px; height:',$height,'px;" allowTransparency="true"></iframe>';
			
		}
		else if ( $type == WPC_TYPE_XFBML ){
			
			echo '<fb:activity site="',$domain,'" width="',$width,'" height="',$height,'" header="',$header,'" colorscheme="',$colorscheme,'" font="',$font,'" border_color="',$border_color,'"></fb:activity>';
			
		}
		
		echo "\n", '<!-- Wordpress Connect Activity Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$type = $instance['type'];
		$domain = $instance['domain'];
		$width = $instance['width'];
		$height = $instance['height'];
		$header = $instance['header'];
		$colorscheme = $instance['colorscheme'];
		$font = $instance['font'];
		$border_color = $instance['border_color'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		}

		WordpressConnectWidgetActivity::printWidget(
			$type,
			$domain, 
			$width, 
			$height, 
			( $header ) ? 'true' : 'false',
			$colorscheme,
			$font,
			$border_color
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = $new_instance['title'];
		$instance['type'] = $new_instance['type'];
		$instance['domain'] = $new_instance['domain'];
		$instance['width'] = $new_instance['width'];
		$instance['height'] = $new_instance['height'];
		$instance['header'] = isset( $new_instance['header'] );
		$instance['colorscheme'] = $new_instance['colorscheme'];
		$instance['font'] = $new_instance['font'];
		$instance['border_color'] = $new_instance['border_color'];
		
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_ACTIVITY_NAME,
			'type' => WPC_TYPE_XFBML,
			'domain' => '',
			'width' => 200,
			'height' => 300, 
			'header' => TRUE, 
			'colorscheme' => 'light',
			'font' => '',
			'border_color' => ''
		);
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>">Type: <acronym title="The rendering type of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" >
				<option <?php echo ( $instance['type'] == WPC_TYPE_IFRAME ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_IFRAME; ?>"><?php echo WPC_TYPE_IFRAME; ?></option>
				<option <?php echo ( $instance['type'] == WPC_TYPE_XFBML ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_XFBML; ?>"><?php echo WPC_TYPE_XFBML;?></option>
			</select> 
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'domain' ); ?>">Domain: <acronym title="The domain to show activity for. In XFBML mode, defaults to the domain the widget is on.">(?)</acronym></label>
			<input type="text" id="<?php echo $this->get_field_id( 'domain' ); ?>" name="<?php echo $this->get_field_name( 'domain' ); ?>"  value="<?php echo $instance['domain']; ?>"/>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>">Height: <acronym title="The height of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'height' ); ?>" size="8" value="<?php echo $instance['height']; ?>" />
		</p>
				
		<p>
			<label for="<?php echo $this->get_field_id( 'header' ); ?>">Header: <acronym title="Show the Facebook header on the widget.">(?)</acronym></label>
			<input type="checkbox" <?php echo ( $instance['header'] === TRUE ) ? 'checked="checked"' : ''; ?> id="<?php echo $this->get_field_id( 'header' ); ?>" name="<?php echo $this->get_field_name( 'header' ); ?>" /> Show Header
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'colorscheme' ); ?>">Color Scheme: <acronym title="The color scheme of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'colorscheme' ); ?>" name="<?php echo $this->get_field_name( 'colorscheme' ); ?>" >
				<option <?php echo ( $instance['colorscheme'] == 'light' ) ? 'selected="selected"' : ''; ?> value="light">ligth</option>
				<option <?php echo ( $instance['colorscheme'] == 'dark' ) ? 'selected="selected"' : ''; ?> value="dark">dark</option>
			</select> 
		</p>		

		<p>
			<label for="<?php echo $this->get_field_id( 'font' ); ?>">Font: <acronym title="The font of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'font' ); ?>" name="<?php echo $this->get_field_name( 'font' ); ?>" >
				<option <?php echo ( $instance['font'] == '' ) ? 'selected="selected"' : ''; ?>></option>
				<option <?php echo ( $instance['font'] == 'arial' ) ? 'selected="selected"' : ''; ?> value="arial">arial</option>
				<option <?php echo ( $instance['font'] == 'lucida grande' ) ? 'selected="selected"' : ''; ?> value="lucida grande">lucida grande</option>
				<option <?php echo ( $instance['font'] == 'segoe ui' ) ? 'selected="selected"' : ''; ?> value="segoe ui">segoe ui</option>
				<option <?php echo ( $instance['font'] == 'tahoma' ) ? 'selected="selected"' : ''; ?> value="tahoma">tahoma</option>
				<option <?php echo ( $instance['font'] == 'trebuchet ms' ) ? 'selected="selected"' : ''; ?> value="trebuchet ms">trebuchet ms</option>
				<option <?php echo ( $instance['font'] == 'verdana' ) ? 'selected="selected"' : ''; ?> value="verdana">verdana</option>				
			</select> 
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'border_color' ); ?>">Border Color: <acronym title="The border color of the widget.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'border_color' ); ?>" size="12" value="<?php echo $instance['border_color']; ?>" />
		</p>		
		
<?php
	}
}


?>