<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetComments.php
 * 
 * This class provides methods for the Comments Feed widget
 */
class WordpressConnectWidgetComments extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetComments
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetComments() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-comments', 
			'description' => 'Wordpress Connect Comments Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-comments', 'WPC Comments Widget', $widget_ops );		
		
	}

	/**
	 * Returns the html/xfbml widget code
	 */
	public static function getWidgetCode( $site, $width, $number_of_comments ){
		
		$code = '<!-- Wordpress Connect Comments Widget v' . WPC_VERSION .'-->' . "\n";
		$code .= '<fb:comments xid="' . md5( $site ) . '" url="' . $site . '" site="' . $site . '" width="' . $width . '" numposts="' . $number_of_comments . '"></fb:comments>';
		$code .= "\n" . '<!-- Wordpress Connect Comments Widget -->' . "\n";		
		
		return $code;
		
	}

	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $site, $width, $number_of_comments ){
			
		echo "\n" , '<!-- Wordpress Connect Comments Widget v',WPC_VERSION,'-->' , "\n";
		echo '<fb:comments xid="', md5( $site ) ,'" site="',$site,'" width="',$width,'" numposts="',$number_of_comments,'"></fb:comments>';
		echo "\n" , '<!-- Wordpress Connect Comments Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$site = $instance['site'];
		$width = $instance['width'];
		$number_of_comments = $instance['number_of_comments'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		} 

		WordpressConnectWidgetComments::printWidget(
			$site, 
			$width, 
			$number_of_comments
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = $new_instance['title'];
		$instance['site'] = $new_instance['site'];
		$instance['width'] = $new_instance['width'];
		$instance['number_of_comments'] = $new_instance['number_of_comments'];
		
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_COMMENTS_NAME,
			'site' => '',
			'width' => 200,
			'number_of_comments' => 8
		);
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'site' ); ?>">Site: <acronym title="URL (domain) of the site where the widget appears">(?)</acronym></label>
			<input type="text" id="<?php echo $this->get_field_id( 'site' ); ?>" name="<?php echo $this->get_field_name( 'site' ); ?>"  value="<?php echo $instance['site']; ?>"/>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number_of_comments' ); ?>">Number of Comments: <acronym title="The number of comments to display, or 0 to hide all comments.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'number_of_comments' ); ?>" size="8" value="<?php echo $instance['number_of_comments']; ?>" />
		</p>
		
<?php
	}
}


?>