<?php

require_once( 'WordpressConnectConstants.php' );

/**
 * @author Tomas Vorobjov
 * @version 1.0
 * @date 28 May 2019
 * 
 * @file WordpressConnectWidgetLikeButton.php
 * 
 * This class provides methods for the Like Button widget
 */
class WordpressConnectWidgetLikeButton extends WP_Widget {
	
	/**
	 * Creates new instance of the WordpressConnectWidgetLikeButton
	 * 
	 * @since 1.0
	 */
	function WordpressConnectWidgetLikeButton() {
		
		$widget_ops = array(
			'classname' => 'widget-wpc-like-button', 
			'description' => 'Wordpress Connect Like Button Widget' 
		);
		
		$this->WP_Widget( 'widget-wpc-like-button', 'WPC Like Button Widget', $widget_ops );		
		
	}

	/**
	 * Returns the html/xfbml widget code
	 */
	public static function getWidgetCode( $type, $url, $layout, $show_faces, $width, $height, $action, $font = '', $colorscheme = '' ){
		
		$code = '<!-- Wordpress Connect Like Button Widget v' . WPC_VERSION . '-->' . "\n";
		
		if ( $type == WPC_TYPE_IFRAME ){
			
			$code .= '<iframe src="http://www.facebook.com/plugins/like.php?href=' . urlencode($url) . '&amp;layout=' . $layout . '&amp;show_faces=' . $show_faces . '&amp;width=' . $width . '&amp;action=' . $action . '&amp;font=' . $font . '&amp;colorscheme=' . $colorscheme . '&amp;height=' . $height . '" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:' . $width . 'px; height:' . $height . 'px;" allowTransparency="true"></iframe>';
		}
		else if ( $type == WPC_TYPE_XFBML ){
			
			$code .=  '<fb:like href="' . $url . '" layout="' . $layout . '" show_faces="' . $show_faces . '" width="' . $width . '" action="' . $action . '" font="' . $font . '" colorscheme="' . $colorscheme . '"></fb:like>';

		}
		
		$code .=  "\n" . '<!-- Wordpress Connect Like Button Widget -->' . "\n";		
		
		return $code;
		
	}

	/**
	 * Prints the content of the widget.
	 */
	public static function printWidget( $type, $url, $layout, $show_faces, $width, $height, $action, $font = '', $colorscheme = '' ){
			
		echo "\n" . '<!-- Wordpress Connect Like Button Widget v',WPC_VERSION,'-->' , "\n";
		
		if ( $type == WPC_TYPE_IFRAME ){
			
			echo '<iframe src="http://www.facebook.com/plugins/like.php?href=',urlencode($url),'&amp;layout=',$layout,'&amp;show_faces=',$show_faces,'&amp;width=',$width,'&amp;action=',$action,'&amp;font=',$font,'&amp;colorscheme=',$colorscheme,'&amp;height=',$height,'" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:',$width,'px; height:',$height,'px;" allowTransparency="true"></iframe>';
		}
		else if ( $type == WPC_TYPE_XFBML ){
			
			echo '<fb:like href="',$url,'" layout="',$layout,'" show_faces="',$show_faces,'" width="',$width,'" action="',$action,'" font="',$font,'" colorscheme="',$colorscheme,'"></fb:like>';

		}
		
		echo "\n" . '<!-- Wordpress Connect Like Button Widget -->' , "\n";
		
	}

	/**
	 * Prints the widget
	 * 
	 * @since 1.0
	 */ 
	function widget( $args, $instance ) {
		
		extract( $args );

		/* User-selected settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		
		$type = $instance['type'];
		$url = $instance['url'];
		$layout = $instance['layout'];
		$show_faces = $instance['show_faces'];
		$width = $instance['width'];
		$height = $instance['height'];
		$action = $instance['action'];
		$font = $instance['font'];
		$colorscheme = $instance['colorscheme'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title ){
			echo $before_title . $title . $after_title;
		}

		WordpressConnectWidgetLikeButton::printWidget(
			$type,
			$url,
			$layout,
			( $show_faces ) ? 'true' : 'false',
			$width, 
			$height, 
			$action,
			$font,
			$colorscheme
		);
				
		/* After widget (defined by themes). */
		echo $after_widget;
	}
 
 	/**
	 * Saves the widget
	 * 
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags (if needed) and update the widget settings. */
		$instance['title'] = trim( $new_instance['title'] );
		$instance['type'] = trim( $new_instance['type'] );
		$instance['url'] = trim( $new_instance['url'] );
		$instance['layout'] = trim( $new_instance['layout'] );
		$instance['show_faces'] = isset( $new_instance['show_faces'] );
		$instance['width'] = trim( $new_instance['width'] );
		$instance['height'] = trim( $new_instance['height'] );
		$instance['action'] = trim( $new_instance['action'] );
		$instance['font'] = trim( $new_instance['font'] );
		$instance['colorscheme'] = trim( $new_instance['colorscheme'] );
				
		return $instance;
		
	}
 
 	/**
	 * Widget form in back-end
	 * 
	 * @since 1.0
	 */
	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 
			'title' => WPC_WIDGET_LIKE_BUTTON_NAME,
			'type' => WPC_TYPE_XFBML,
			'url' => '',
			'layout' => 'standard',
			'show_faces' => TRUE,
			'width' => 200,
			'height' => 80,
			'action' => 'like', 
			'font' => '',
			'colorscheme' => 'light'
		);
		$instance = wp_parse_args( (array) $instance, $defaults );		
		
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>">Type: <acronym title="The rendering type of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" >
				<option <?php echo ( $instance['type'] == WPC_TYPE_IFRAME ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_IFRAME; ?>"><?php echo WPC_TYPE_IFRAME; ?></option>
				<option <?php echo ( $instance['type'] == WPC_TYPE_XFBML ) ? 'selected="selected"' : ''; ?> value="<?php echo WPC_TYPE_XFBML; ?>"><?php echo WPC_TYPE_XFBML;?></option>
			</select> 
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>">URL to Like: <acronym title="The URL to like. In XFBML, defaults to the current page.">(?)</acronym></label>
			<input type="text" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>"  value="<?php echo $instance['url']; ?>"/>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>">Layout Style: <acronym title="Determines the amount of social context next to the button.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" >
				<option <?php echo ( $instance['layout'] == 'standard' ) ? 'selected="selected"' : ''; ?> value="standard">standard</option>
				<option <?php echo ( $instance['layout'] == 'button_count' ) ? 'selected="selected"' : ''; ?> value="button_count">button_count</option>
			</select> 
		</p>		
				
		<p>
			<label for="<?php echo $this->get_field_id( 'show_faces' ); ?>">Show Faces: <acronym title="Show profile pictures below the button.">(?)</acronym></label>
			<input type="checkbox" <?php echo ( $instance['show_faces'] === TRUE ) ? 'checked="checked"' : ''; ?> id="<?php echo $this->get_field_id( 'show_faces' ); ?>" name="<?php echo $this->get_field_name( 'show_faces' ); ?>" /> Show faces
		</p>		
		
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>">Width: <acronym title="The width of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" size="8" value="<?php echo $instance['width']; ?> "/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>">Height: <acronym title="The height of the widget in pixels.">(?)</acronym></label>
			<input type="text" name="<?php echo $this->get_field_name( 'height' ); ?>" size="8" value="<?php echo $instance['height']; ?>" /> (iframe type only)
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'action' ); ?>">Verb to display: <acronym title="The verb to display in the button. Currently only 'like' and 'recommend' are supported.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'action' ); ?>" name="<?php echo $this->get_field_name( 'action' ); ?>" >
				<option <?php echo ( $instance['layout'] == 'like' ) ? 'selected="selected"' : ''; ?> value="like">like</option>
				<option <?php echo ( $instance['layout'] == 'recommend' ) ? 'selected="selected"' : ''; ?> value="recommend">recommend</option>
			</select> 
		</p>		

		<p>
			<label for="<?php echo $this->get_field_id( 'font' ); ?>">Font: <acronym title="The font of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'font' ); ?>" name="<?php echo $this->get_field_name( 'font' ); ?>" >
				<option <?php echo ( $instance['font'] == '' ) ? 'selected="selected"' : ''; ?>></option>
				<option <?php echo ( $instance['font'] == 'arial' ) ? 'selected="selected"' : ''; ?> value="arial">arial</option>
				<option <?php echo ( $instance['font'] == 'lucida grande' ) ? 'selected="selected"' : ''; ?> value="lucida grande">lucida grande</option>
				<option <?php echo ( $instance['font'] == 'segoe ui' ) ? 'selected="selected"' : ''; ?> value="segoe ui">segoe ui</option>
				<option <?php echo ( $instance['font'] == 'tahoma' ) ? 'selected="selected"' : ''; ?> value="tahoma">tahoma</option>
				<option <?php echo ( $instance['font'] == 'trebuchet ms' ) ? 'selected="selected"' : ''; ?> value="trebuchet ms">trebuchet ms</option>
				<option <?php echo ( $instance['font'] == 'verdana' ) ? 'selected="selected"' : ''; ?> value="verdana">verdana</option>				
			</select> 
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'colorscheme' ); ?>">Color Scheme: <acronym title="The color scheme of the widget.">(?)</acronym></label>
			<select id="<?php echo $this->get_field_id( 'colorscheme' ); ?>" name="<?php echo $this->get_field_name( 'colorscheme' ); ?>" >
				<option <?php echo ( $instance['colorscheme'] == 'light' ) ? 'selected="selected"' : ''; ?> value="light">ligth</option>
				<option <?php echo ( $instance['colorscheme'] == 'dark' ) ? 'selected="selected"' : ''; ?> value="dark">dark</option>
			</select> 
		</p>	
		
<?php
	}
}


?>